@@ -16,13 +16,14 @@
 
 #line 6 "join.y"
 
-#include "types.c"
-#include "sem.c"
+#include "types.h"
+#include "datatypes.c"
 #include "semantics.c"
 
 sem *global_code;
+int global_input_line;
 
-#line 13 "join.y"
+#line 14 "join.y"
 typedef union {
 explisttype nl;
 exptype ex;
@@ -126,10 +127,10 @@ static const short yyrhs[] = {    21,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    54,    57,    58,    59,    60,    61,    63,    64,    65,    68,
-    69,    72,    73,    76,    77,    80,    81,    82,    83,    84,
-    87,    88,    92,    96,    97,   101,   103,   106,   107,   110,
-   111
+    55,    58,    59,    60,    61,    62,    64,    65,    66,    69,
+    70,    73,    74,    77,    78,    81,    82,    83,    84,    85,
+    88,    89,    93,    97,    98,   102,   104,   107,   108,   111,
+   112
 };
 
 static const char * const yytname[] = {   "$","error","$illegal.","NAME","DEF",
@@ -673,99 +674,99 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 54 "join.y"
+#line 55 "join.y"
 { global_code=program_from_process(yyvsp[0].pr); ;
     break;}
 case 3:
-#line 58 "join.y"
+#line 59 "join.y"
 { yyval.pr = yyvsp[-1].pr ;
     break;}
 case 4:
-#line 59 "join.y"
+#line 60 "join.y"
 { yyval.pr = empty_process(); ;
     break;}
 case 5:
-#line 60 "join.y"
+#line 61 "join.y"
 { yyval.pr = proc_from_proc_message(yyvsp[-2].pr,yyvsp[0].pr);;
     break;}
 case 6:
-#line 62 "join.y"
+#line 63 "join.y"
 {yyval.pr = proc_from_name_def_proc(yyvsp[-5].na,yyvsp[-2].df,yyvsp[0].pr);;
     break;}
 case 7:
-#line 63 "join.y"
+#line 64 "join.y"
 {yyval.pr=proc_from_def_proc(yyvsp[-2].df,yyvsp[0].pr);;
     break;}
 case 10:
-#line 68 "join.y"
+#line 69 "join.y"
 {yyval.pr = message_from_name_explist(yyvsp[-3].na,yyvsp[-1].nl);;
     break;}
 case 12:
-#line 72 "join.y"
+#line 73 "join.y"
 { yyval.nl = empty_explist(); ;
     break;}
 case 14:
-#line 76 "join.y"
+#line 77 "join.y"
 { yyval.nl = explist_from_exp_explist(yyvsp[0].ex,empty_explist()); ;
     break;}
 case 15:
-#line 77 "join.y"
+#line 78 "join.y"
 { yyval.nl = explist_from_exp_explist(yyvsp[-2].ex,yyvsp[0].nl); ;
     break;}
 case 16:
-#line 80 "join.y"
+#line 81 "join.y"
 { yyval.ex = exp_from_name(yyvsp[0].na); ;
     break;}
 case 17:
-#line 81 "join.y"
+#line 82 "join.y"
 { yyval.ex = exp_from_int(yyvsp[0].ic); ;
     break;}
 case 18:
-#line 82 "join.y"
+#line 83 "join.y"
 { yyval.ex = exp_from_str(yyvsp[0].sc); ;
     break;}
 case 19:
-#line 83 "join.y"
+#line 84 "join.y"
 { yyval.ex = exp_from_boole(yyvsp[0].bc); ;
     break;}
 case 20:
-#line 84 "join.y"
+#line 85 "join.y"
 { yyval.ex = exp_from_wildcard(); ;
     break;}
 case 21:
-#line 87 "join.y"
+#line 88 "join.y"
 { yyval.df=definition_from_basicdef(yyvsp[0].bd); ;
     break;}
 case 22:
-#line 89 "join.y"
+#line 90 "join.y"
 { yyval.df=definition_from_definition_basicdef(yyvsp[-2].df,yyvsp[0].bd); ;
     break;}
 case 23:
-#line 93 "join.y"
+#line 94 "join.y"
 { yyval.bd=basicdef_from_jp_process(yyvsp[-2].jp,yyvsp[0].pr); ;
     break;}
 case 24:
-#line 96 "join.y"
+#line 97 "join.y"
 { yyval.jp=joinpattern_from_receiver(yyvsp[0].rc); ;
     break;}
 case 25:
-#line 98 "join.y"
+#line 99 "join.y"
 { yyval.jp=jp_from_jp_receiver(yyvsp[-2].jp,yyvsp[0].rc); ;
     break;}
 case 26:
-#line 102 "join.y"
+#line 103 "join.y"
 { yyval.rc=receiver_from_name_parameterlist(yyvsp[-3].na,yyvsp[-1].pl); ;
     break;}
 case 28:
-#line 106 "join.y"
+#line 107 "join.y"
 { yyval.pl=empty_parameterlist(); ;
     break;}
 case 30:
-#line 110 "join.y"
+#line 111 "join.y"
 { yyval.pl=pl_from_name_pl(yyvsp[0].na,empty_parameterlist()); ;
     break;}
 case 31:
-#line 111 "join.y"
+#line 112 "join.y"
 { yyval.pl=pl_from_name_pl(yyvsp[-2].na,yyvsp[0].pl); ;
     break;}
 }
@@ -966,7 +967,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 114 "join.y"
+#line 115 "join.y"
 
 
 #include "lex.yy.c"
